@@ -1,4 +1,4 @@
 # -*- coding: utf-8 -*-
 """AiiDA-ORCA Plugin utils"""
 
-from .input_generator import OrcaInput
+from .input_generator import render_orca_input
